Skip to contents

Calculates soil carbon This should be put into the SDA procedure.

Usage

calculateGridcellSOC(
  model.state,
  pools = c("SOILSTRUCT", "SOILMETA", "SOILMICRO", "SLOWSOM", "PASSIVESOM")
)

Arguments

model.state

A large multiply-nested list containing the entire LPJ-GUESS state as read by function readStateBinary.LPJGUESS

pools

"SOILSTRUCT","SOILMETA","SOILMICRO","SLOWSOM","PASSIVESOM" (see somdynam.cpp)

Value

The total SOC in Gridcell. The unit is consistent with cmass in state, usually kg C m-2

Author

Yinghao Sun