Calculates soil carbon This should be put into the SDA procedure.
Usage
calculateGridcellSOC(
model.state,
pools = c("SOILSTRUCT", "SOILMETA", "SOILMICRO", "SLOWSOM", "PASSIVESOM")
)Calculates soil carbon This should be put into the SDA procedure.
calculateGridcellSOC(
model.state,
pools = c("SOILSTRUCT", "SOILMETA", "SOILMICRO", "SLOWSOM", "PASSIVESOM")
)